==> insighttoolkit4_4.9.0.orig.tar.xz: InsightToolkit-4.9.0/Modules/ThirdParty/MINC/src/libminc/config.h.cmake <==
/* various defines */

#ifndef MINC2
#define MINC2 @MINC2@
#endif

#cmakedefine DEBUG 1

#define MINC_PACKAGE_NAME "@LIBMINC_PACKAGE_NAME@"
#define MINC_PACKAGE_BUGREPORT "@LIBMINC_PACKAGE_BUGREPORT@"
#define MINC_PACKAGE_VERSION "@LIBMINC_PACKAGE_VERSION@"
#define MINC_VERSION "@LIBMINC_PACKAGE_VERSION@"
#define MINC_PACKAGE_STRING "@LIBMINC_PACKAGE_STRING@"

#cmakedefine HAVE_MINC1 1 
#cmakedefine HAVE_MINC2 1

#ifndef H5Acreate_vers
#define H5Acreate_vers 2
#endif //H5Acreate_vers

#cmakedefine HAVE_MKSTEMP 1 
#cmakedefine HAVE_STRERROR 1 
#cmakedefine HAVE_FLOAT_H 1 

#cmakedefine HAVE_COPYSIGN 1 
#cmakedefine HAVE_ROUND 1 

#cmakedefine HAVE_DIRENT_H 1 
#cmakedefine HAVE_DLFCN_H 1 
#cmakedefine HAVE_FCNTL_H 1 
#cmakedefine HAVE_FORK 1 
#cmakedefine HAVE_GETPWNAM 1 
#cmakedefine HAVE_INT16_T 1 
#cmakedefine HAVE_INT32_T 1 
#cmakedefine HAVE_INTTYPES_H 1 
#cmakedefine HAVE_MEMORY_H 1 
#cmakedefine HAVE_MKSTEMP 1 
#cmakedefine HAVE_NDIR_H 1 
#cmakedefine HAVE_POPEN 1 
#cmakedefine HAVE_PWD_H 1 
#cmakedefine HAVE_SELECT 1 
#cmakedefine HAVE_STDINT_H 1 
#cmakedefine HAVE_STDLIB_H 1 
#cmakedefine HAVE_STRDUP 1 
#cmakedefine HAVE_SYSCONF 1 
#cmakedefine HAVE_SYSTEM 1 
#cmakedefine HAVE_SYS_DIR_H 1 
#cmakedefine HAVE_SYS_NDIR_H 1 
#cmakedefine HAVE_SYS_STAT_H 1 
#cmakedefine HAVE_SYS_TIME_H 1 
#cmakedefine HAVE_SYS_TYPES_H 1 
#cmakedefine HAVE_SYS_WAIT_H 1 
#cmakedefine HAVE_TEMPNAM 1 
#cmakedefine HAVE_TMPNAM 1 
#cmakedefine HAVE_UNISTD_H 1 
#cmakedefine HAVE_VALUES_H 1 
#cmakedefine HAVE_VFORK 1 
#cmakedefine HAVE_VFORK_H 1 
#cmakedefine HAVE_WORKING_FORK 1 
#cmakedefine HAVE_WORKING_VFORK 1 
#cmakedefine HAVE_ZLIB 1 
#cmakedefine HAVE_STRINGS_H 1 
#cmakedefine HAVE_STRING_H 1 
#cmakedefine HAVE_SRAND48 1 
#cmakedefine HAVE_DRAND48 1 
#cmakedefine HAVE_SLEEP 1 
#cmakedefine HAVE_CLOCK_GETTIME 1
#cmakedefine HAVE_GETTIMEOFDAY 1

==> insighttoolkit5_5.4.3.orig.tar.xz: InsightToolkit-5.4.3/Modules/ThirdParty/MINC/src/libminc/config.h.cmake <==
/* various defines */

#ifndef MINC2
#define MINC2 @MINC2@
#endif

#cmakedefine DEBUG 1

#define MINC_PACKAGE_NAME "@LIBMINC_PACKAGE_NAME@"
#define MINC_PACKAGE_BUGREPORT "@LIBMINC_PACKAGE_BUGREPORT@"
#define MINC_PACKAGE_VERSION "@LIBMINC_PACKAGE_VERSION@"
#define MINC_VERSION "@LIBMINC_PACKAGE_VERSION@"
#define MINC_PACKAGE_STRING "@LIBMINC_PACKAGE_STRING@"

#cmakedefine HAVE_MINC1 1 
#cmakedefine HAVE_MINC2 1
#cmakedefine LIBMINC_NIFTI_SUPPORT 1

#ifndef H5Acreate_vers
#define H5Acreate_vers 2
#endif //H5Acreate_vers

#cmakedefine HAVE_MKSTEMP 1 
#cmakedefine HAVE_STRERROR 1 
#cmakedefine HAVE_FLOAT_H 1 

#cmakedefine HAVE_COPYSIGN 1 
#cmakedefine HAVE_ROUND 1 

#cmakedefine HAVE_DIRENT_H 1 
#cmakedefine HAVE_DLFCN_H 1 
#cmakedefine HAVE_FCNTL_H 1 
#cmakedefine HAVE_FORK 1 
#cmakedefine HAVE_GETPWNAM 1 
#cmakedefine HAVE_INT16_T 1 
#cmakedefine HAVE_INT32_T 1 
#cmakedefine HAVE_INTTYPES_H 1 
#cmakedefine HAVE_MEMORY_H 1 
#cmakedefine HAVE_MKSTEMP 1 
#cmakedefine HAVE_NDIR_H 1 
#cmakedefine HAVE_POPEN 1 
#cmakedefine HAVE_PWD_H 1 
#cmakedefine HAVE_SELECT 1 
#cmakedefine HAVE_STDINT_H 1 
#cmakedefine HAVE_STDLIB_H 1 
#cmakedefine HAVE_STRDUP 1 
#cmakedefine HAVE_SYSCONF 1 
#cmakedefine HAVE_SYSTEM 1 
#cmakedefine HAVE_SYS_DIR_H 1 
#cmakedefine HAVE_SYS_NDIR_H 1 
#cmakedefine HAVE_SYS_STAT_H 1 
#cmakedefine HAVE_SYS_TIME_H 1 
#cmakedefine HAVE_TIME_H 1 
#cmakedefine HAVE_SYS_TYPES_H 1 
#cmakedefine HAVE_SYS_WAIT_H 1 
#cmakedefine HAVE_SYS_SELECT_H 1
#cmakedefine HAVE_TEMPNAM 1 
#cmakedefine HAVE_TMPNAM 1 
#cmakedefine HAVE_UNISTD_H 1 
#cmakedefine HAVE_VALUES_H 1 
#cmakedefine HAVE_VFORK 1 
#cmakedefine HAVE_VFORK_H 1 
#cmakedefine HAVE_WORKING_FORK 1 
#cmakedefine HAVE_WORKING_VFORK 1 
#cmakedefine HAVE_ZLIB 1 
#cmakedefine HAVE_STRINGS_H 1 
#cmakedefine HAVE_STRING_H 1 
#cmakedefine HAVE_SRAND48 1 
#cmakedefine HAVE_DRAND48 1 
#cmakedefine HAVE_SLEEP 1 
#cmakedefine HAVE_CLOCK_GETTIME 1
#cmakedefine HAVE_GETTIMEOFDAY 1
#cmakedefine HAVE_RINT 1
